==> typo3_src-4.4.14.tar.gz: typo3_src-4.4.14/typo3/sysext/rsaauth/sv1/storage/class.tx_rsaauth_split_storage.php <==
<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2009-2010 Dmitry Dulepov <dmitry@typo3.org>
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

/**
 * [CLASS/FUNCTION INDEX of SCRIPT]
 *
 * $Id$
 */

require_once(t3lib_extMgm::extPath('rsaauth', 'sv1/storage/class.tx_rsaauth_abstract_storage.php'));

/**
 * This class contains a "split" storage for the data. It keeps part of the data
 * in the database, part in the database.
 *
 * @author	Dmitry Dulepov <dmitry@typo3.org>
 * @package	TYPO3
 * @subpackage	tx_rsaauth
 */
class tx_rsaauth_split_storage extends tx_rsaauth_abstract_storage {

	/**
	 * Creates an instance of this class. It checks and initializes PHP
	 * sessions if necessary.
	 *
	 * @return	void
	 */
	public function __construct() {
		if (session_id() === '') {
			session_start();
		}
	}

	/**
	 * Obtains a key from the database
	 *
	 * @return string	The key or null
	 * @see tx_rsaauth_abstract_storage::get()
	 */
	public function get() {
		$result = null;

		list($keyId, $keyPart1) = $_SESSION['tx_rsaauth_key'];
		if (t3lib_div::testInt($keyId)) {

			// Remove expired keys (more than 30 minutes old)
			$GLOBALS['TYPO3_DB']->exec_DELETEquery('tx_rsaauth_keys',
						'crdate<' . ($GLOBALS['EXEC_TIME'] - 30 * 60));

			// Get our value
			list($row) = $GLOBALS['TYPO3_DB']->exec_SELECTgetRows('key_value',
				'tx_rsaauth_keys', 'uid=' . $keyId);
			if (is_array($row)) {
				$result = $keyPart1 . $row['key_value'];
			}
		}
		return $result;
	}

	/**
	 * Adds a key to the storage or removes existing key
	 *
	 * @param	string	$key	The key
	 * @return	void
	 * @see	tx_rsaauth_abstract_storage::put()
	 */
	public function put($key) {
		if ($key == null) {
			// Remove existing key
			list($keyId) = $_SESSION['tx_rsaauth_key'];

			if (t3lib_div::testInt($keyId)) {
				$GLOBALS['TYPO3_DB']->exec_DELETEquery('tx_rsaauth_keys',
					'uid=' . $keyId);
				unset($_SESSION['tx_rsaauth_key']);
			}
		}
		else {
			// Add key

			// Get split point. First part is always smaller than the second
			// because it goes to the file system
			$keyLength = strlen($key);
			$splitPoint = rand(intval($keyLength/10), intval($keyLength/2));

			// Get key parts
			$keyPart1 = substr($key, 0, $splitPoint);
			$keyPart2 = substr($key, $splitPoint);

			// Store part of the key in the database
			//
			// Notice: we may not use TCEmain below to insert key part into the
			// table because TCEmain requires a valid BE user!
			$time = $GLOBALS['EXEC_TIME'];
			$GLOBALS['TYPO3_DB']->exec_INSERTquery('tx_rsaauth_keys', array(
				'pid' => 0,
				'crdate' => $time,
				'key_value' => $keyPart2
			));
			$keyId = $GLOBALS['TYPO3_DB']->sql_insert_id();

			// Store another part in session
			$_SESSION['tx_rsaauth_key'] = array($keyId, $keyPart1);
		}

		// Remove expired keys (more than 30 minutes old)
		$GLOBALS['TYPO3_DB']->exec_DELETEquery('tx_rsaauth_keys',
					'crdate<' . ($GLOBALS['EXEC_TIME'] - 30 * 60));
	}
}

if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/rsaauth/sv1/storage/class.tx_rsaauth_split_storage.php'])	{
	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/rsaauth/sv1/storage/class.tx_rsaauth_split_storage.php']);
}

?>

==> typo3_src-4.5.7.tar.gz: typo3_src-4.5.7/typo3/sysext/rsaauth/sv1/storage/class.tx_rsaauth_split_storage.php <==
<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2009-2011 Dmitry Dulepov <dmitry@typo3.org>
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

/**
 * [CLASS/FUNCTION INDEX of SCRIPT]
 *
 * $Id$
 */

require_once(t3lib_extMgm::extPath('rsaauth', 'sv1/storage/class.tx_rsaauth_abstract_storage.php'));

/**
 * This class contains a "split" storage for the data. It keeps part of the data
 * in the database, part in the database.
 *
 * @author	Dmitry Dulepov <dmitry@typo3.org>
 * @package	TYPO3
 * @subpackage	tx_rsaauth
 */
class tx_rsaauth_split_storage extends tx_rsaauth_abstract_storage {

	/**
	 * Creates an instance of this class. It checks and initializes PHP
	 * sessions if necessary.
	 *
	 * @return	void
	 */
	public function __construct() {
		if (!isset($_SESSION) || !is_array($_SESSION)) {
			session_start();
		}
	}

	/**
	 * Obtains a key from the database
	 *
	 * @return string	The key or null
	 * @see tx_rsaauth_abstract_storage::get()
	 */
	public function get() {
		$result = null;

		list($keyId, $keyPart1) = $_SESSION['tx_rsaauth_key'];
		if (t3lib_div::testInt($keyId)) {

			// Remove expired keys (more than 30 minutes old)
			$GLOBALS['TYPO3_DB']->exec_DELETEquery('tx_rsaauth_keys',
						'crdate<' . ($GLOBALS['EXEC_TIME'] - 30 * 60));

				// Get our value
			$row = $GLOBALS['TYPO3_DB']->exec_SELECTgetSingleRow('key_value',
				'tx_rsaauth_keys', 'uid=' . $keyId);
			if (is_array($row)) {
				$result = $keyPart1 . $row['key_value'];
			}
		}
		return $result;
	}

	/**
	 * Adds a key to the storage or removes existing key
	 *
	 * @param	string	$key	The key
	 * @return	void
	 * @see	tx_rsaauth_abstract_storage::put()
	 */
	public function put($key) {
		if ($key == null) {
			// Remove existing key
			list($keyId) = $_SESSION['tx_rsaauth_key'];

			if (t3lib_div::testInt($keyId)) {
				$GLOBALS['TYPO3_DB']->exec_DELETEquery('tx_rsaauth_keys',
					'uid=' . $keyId);
				unset($_SESSION['tx_rsaauth_key']);
			}
		}
		else {
			// Add key

			// Get split point. First part is always smaller than the second
			// because it goes to the file system
			$keyLength = strlen($key);
			$splitPoint = rand(intval($keyLength/10), intval($keyLength/2));

			// Get key parts
			$keyPart1 = substr($key, 0, $splitPoint);
			$keyPart2 = substr($key, $splitPoint);

			// Store part of the key in the database
			//
			// Notice: we may not use TCEmain below to insert key part into the
			// table because TCEmain requires a valid BE user!
			$time = $GLOBALS['EXEC_TIME'];
			$GLOBALS['TYPO3_DB']->exec_INSERTquery('tx_rsaauth_keys', array(
				'pid' => 0,
				'crdate' => $time,
				'key_value' => $keyPart2
			));
			$keyId = $GLOBALS['TYPO3_DB']->sql_insert_id();

			// Store another part in session
			$_SESSION['tx_rsaauth_key'] = array($keyId, $keyPart1);
		}

		// Remove expired keys (more than 30 minutes old)
		$GLOBALS['TYPO3_DB']->exec_DELETEquery('tx_rsaauth_keys',
					'crdate<' . ($GLOBALS['EXEC_TIME'] - 30 * 60));
	}
}

if (defined('TYPO3_MODE') && isset($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['ext/rsaauth/sv1/storage/class.tx_rsaauth_split_storage.php'])) {
	include_once($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['ext/rsaauth/sv1/storage/class.tx_rsaauth_split_storage.php']);
}

?>
